@@ -865,6 +865,6 @@ struct oft Offset_Table[]={
 0xE01F0,0xEFFFF,OFT_UNDEF,
 0xF0000,0xFFFFD,OFT_NOINF,
 0xFFFFE,0xFFFFF,OFT_UNDEF,
-0x100000,0x10FFFD,OFT_NOINF,
+0x100000,0x10FFFF,OFT_NOINF,
 };
 int Offset_Entries = sizeof(Offset_Table)/sizeof(struct oft);
