@@ -1,4 +1,4 @@
-/* Time-stamp: <2007-06-30 00:07:33 poser>
+/* Time-stamp: <2008-04-03 19:01:51 poser>
  *
  * Prints the names of the characters in a Unicode file.
  * 
@@ -6,9 +6,8 @@
  * Copyright (C) 2003-2007 William J. Poser (billposer@alum.mit.edu)
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of version 3 the GNU General Public License
+ * as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  * or go to the web page:  http://www.gnu.org/licenses/gpl.txt.
  */
 
@@ -73,7 +72,7 @@ ShowVersion(void){
   fprintf(stderr,"\n%s  %s\n",pgname,PACKAGE_VERSION);
   fprintf(stderr,"%s\n",compdate);
   fprintf(stderr,"Copyright (C) 2003-2007 William J. Poser\n");
-  fprintf(stderr,"Released under the terms of the GNU General Public License.\n\n");
+  fprintf(stderr,"Released under the terms of the GNU General Public License, version 3.\n\n");
 }
 
 void
@@ -85,23 +84,22 @@ ShowUsage(void){
   fprintf(stderr,"Usage: %s [flags] (<file name>)\n",pgname);
   fprintf(stderr,"       -a Skip ASCII characters.\n");
   fprintf(stderr,"       -A Skip ASCII whitespace characters.\n");
-  fprintf(stderr,"       -b Suppress printing of byte offset.\n");
   fprintf(stderr,"       -B Skip characters within the BMP.\n");
+  fprintf(stderr,"       -s <character offset>  skip to specified character.\n");
+  fprintf(stderr,"       -S <byte offset>  skip to specified byte.\n");
+  fprintf(stderr,"       -l Supply line number.\n");
+  fprintf(stderr,"       -r Supply Unicode range.\n");
+  fprintf(stderr,"       -b Suppress printing of byte offset.\n");
   fprintf(stderr,"       -c Suppress printing of character offset.\n");
   fprintf(stderr,"       -e Suppress printing of encoding.\n");
   fprintf(stderr,"       -g Suppress printing of glyph.\n");
-  fprintf(stderr,"       -h Print help information.\n");
-  fprintf(stderr,"       -l Print line number.\n");
-  fprintf(stderr,"       -n Suppress printing of Unicode name.\n");
   fprintf(stderr,"       -p Suppress printing of headers every screenfull.\n");
-  fprintf(stderr,"       -q Input is native-order UTF-32 [default is UTF-8].\n");
-  fprintf(stderr,"       -r Print Unicode range.\n");
-  fprintf(stderr,"       -s <character offset>  skip to specified character.\n");
-  fprintf(stderr,"       -S <byte offset>  skip to specified byte.\n");
+  fprintf(stderr,"       -n Suppress printing of Unicode name.\n");
   fprintf(stderr,"       -u Suppress printing of UTF-32 code.\n");
+  fprintf(stderr,"       -h Print help information.\n");
   fprintf(stderr,"       -v Print version information.\n");
+  fprintf(stderr,"       -q Input is native-order UTF-32 [default is UTF-8].\n");
   fprintf(stderr,"       -V Validate input (determine whether it is valid UTF-8).\n");
-  putc('\n',stderr);
   fprintf(stderr,"Report bugs to: billposer@alum.mit.edu\n");
   putc('\n',stderr);
 }
